# Generated by Django 2.0.4 on 2018-04-26 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("djnexmo", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="smsmessagepart",
            name="data",
            field=models.BinaryField(max_length=160, null=True),
        ),
        migrations.AlterField(
            model_name="smsmessagepart",
            name="keyword",
            field=models.CharField(max_length=160, null=True),
        ),
        migrations.AlterField(
            model_name="smsmessagepart",
            name="text",
            field=models.CharField(max_length=160, null=True),
        ),
        migrations.AlterField(
            model_name="smsmessagepart",
            name="udh",
            field=models.BinaryField(max_length=160, null=True),
        ),
    ]



from django.conf import settings
import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


def pytest_configure():
    settings.configure(
        DEBUG=True,
        INSTALLED_APPS=["djnexmo"],
        DATABASES={
            "default": {
                "ENGINE": "django.db.backends.sqlite3",
                "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
            }
        },
        SECRET_KEY="this is n0t a seekret",
        NEXMO_SIGNATURE_SECRET="abcdefABCDEF12345",
        LANGUAGE_CODE="en-us",
        TIME_ZONE="UTC",
        USE_I18N=True,
        USE_L10N=True,
        USE_TZ=True,
    )



from django import template
from django.template.defaultfilters import stringfilter

import phonenumbers

register = template.Library()


@register.filter(name="international")
@stringfilter
def international(value):
    value = value.strip()
    if not value.startswith("+"):
        value = "+" + value
    phonenumbers.parse(value)
    return phonenumbers.format_number(
        phonenumbers.parse(value), phonenumbers.PhoneNumberFormat.INTERNATIONAL
    )


@register.filter(name="national")
@stringfilter
def national(value):
    value = value.strip()
    if not value.startswith("+"):
        value = "+" + value
    phonenumbers.parse(value)
    return phonenumbers.format_number(
        phonenumbers.parse(value), phonenumbers.PhoneNumberFormat.NATIONAL
    )



# Generated by Django 2.0.4 on 2018-04-27 15:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("djnexmo", "0003_auto_20180426_1802")]

    operations = [
        migrations.AlterModelOptions(
            name="smsmessagepart", options={"ordering": ("-concat_ref", "concat_part")}
        )
    ]



from setuptools import setup, find_packages


setup(
    name="dj-nexmo",
    version="0.0.1-dev2",
    author="Nexmo Developer Relations",
    author_email="devrel@nexmo.com",
    url="https://developer.nexmo.com/",
    description="Utilities for Django developers using Nexmo's APIs",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages("src"),
    package_dir={"": "src"},
    zip_safe=True,
    entry_points={
        "console_scripts": ["dj = django.core.management:execute_from_command_line"]
    },
    install_requires=[
        "nexmo          ~= 2.1.0",
        "django         >= 2.0.0",
        "attrs          ~= 17.4.0",
        "marshmallow    ~= 3.0.0b8",
        "phonenumbers   ~= 8.9.4",
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: Django :: 2.0",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Communications :: Telephony",
    ],
)



from django.conf import settings

import nexmo

__version__ = '0.0.1-dev2'

default_app_config = "djnexmo.apps.NexmoConfig"

client = nexmo.Client(
    api_key=getattr(settings, "NEXMO_API_KEY", None),
    api_secret=getattr(settings, "NEXMO_API_SECRET", None),
    signature_secret=getattr(settings, "NEXMO_SIGNATURE_SECRET", None),
    signature_method=getattr(settings, "NEXMO_SIGNATURE_METHOD", None),
    application_id=getattr(settings, "NEXMO_APPLICATION_ID", None),
    private_key=getattr(settings, "NEXMO_PRIVATE_KEY", None),
)
